@@ -19,7 +19,7 @@ import tempfile
 import threading
 import time
 import uuid
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 
 import pytest
 from dateutil.tz import tzlocal
@@ -59,8 +59,8 @@ from tests import (
     unittest,
 )
 
-TIME_IN_ONE_HOUR = datetime.utcnow() + timedelta(hours=1)
-TIME_IN_SIX_MONTHS = datetime.utcnow() + timedelta(hours=4320)
+TIME_IN_ONE_HOUR = datetime.now(tz=timezone.utc) + timedelta(hours=1)
+TIME_IN_SIX_MONTHS = datetime.now(tz=timezone.utc) + timedelta(hours=4320)
 
 
 class TestCredentialRefreshRaces(unittest.TestCase):
@@ -1143,3 +1143,24 @@ class SSOSessionTest(BaseEnvVar):
             }
         }
         stubber.add_response(body=json.dumps(response).encode('utf-8'))
+
+
+class TestContextCredentials(unittest.TestCase):
+    ACCESS_KEY = "access-key"
+    SECRET_KEY = "secret-key"
+
+    def _add_fake_creds(self, request, **kwargs):
+        request.context.setdefault('signing', {})
+        request.context['signing']['request_credentials'] = Credentials(
+            self.ACCESS_KEY, self.SECRET_KEY
+        )
+
+    def test_credential_context_override(self):
+        session = StubbedSession()
+        with SessionHTTPStubber(session) as stubber:
+            s3 = session.create_client('s3')
+            s3.meta.events.register('before-sign', self._add_fake_creds)
+            stubber.add_response()
+            s3.list_buckets()
+            request = stubber.requests[0]
+            assert self.ACCESS_KEY in str(request.headers.get('Authorization'))
