@@ -32,11 +32,6 @@ MEMBER_NAME_CHARS = set(string.ascii_letters + string.digits)
 # to reference all the extra output keys. Nothing should ever be added to this
 # list, it represents all the current released paginators that fail this test.
 KNOWN_EXTRA_OUTPUT_KEYS = [
-    'alexaforbusiness.SearchUsers.TotalCount',
-    'alexaforbusiness.SearchProfiles.TotalCount',
-    'alexaforbusiness.SearchSkillGroups.TotalCount',
-    'alexaforbusiness.SearchDevices.TotalCount',
-    'alexaforbusiness.SearchRooms.TotalCount',
     'apigateway.GetApiKeys.warnings',
     'apigateway.GetUsage.usagePlanId',
     'apigateway.GetUsage.startDate',
@@ -46,6 +41,7 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'cloudfront.ListDistributions.DistributionList',
     'cloudfront.ListInvalidations.InvalidationList',
     'cloudfront.ListStreamingDistributions.StreamingDistributionList',
+    'cloudfront.ListKeyValueStores.KeyValueStoreList',
     'codedeploy.ListDeploymentGroups.applicationName',
     'dms.DescribeTableStatistics.ReplicationTaskArn',
     'dms.DescribeReplicationTaskAssessmentResults.BucketName',
@@ -149,6 +145,7 @@ def _pagination_configs():
             yield (op_name, single_config, service_model)
 
 
+@pytest.mark.validates_models
 @pytest.mark.parametrize(
     "operation_name, page_config, service_model", _pagination_configs()
 )
